
Contributing
============

Contributions are welcome, and they are greatly appreciated! Every
little bit helps, and credit will always be given.

You can contribute in many ways:

Types of Contributions
----------------------

Report Bugs
~~~~~~~~~~~

Report bugs at https://github.com/learningequality/kolibri-oidc-client-plugin/issues.

If you are reporting a bug, please include:

* Your operating system name and version.
* Any details about your local setup that might be helpful in troubleshooting.
* Detailed steps to reproduce the bug.

Fix Bugs
~~~~~~~~

Look through the GitHub issues for bugs. Anything tagged with "bug"
is open to whoever wants to implement it.


Other Contributions
~~~~~~~~~~~~~~~~~~~

Most other contributions are best targeted at the main Kolibri project.

Please see https://github.com/learningequality/kolibri/CONTRIBUTING.rst for details.

.. _prtemplate:

Pull Request Template
~~~~~~~~~~~~~~~~~~~~~

Copy-paste the following to your Pull Request description on Github::

    ## Summary

    *Short description*

    ## TODO

    - [ ] Have tests been written for the new code?
    - [ ] Has documentation been written/updated?
    - [ ] New dependencies (if any) added to requirements file
    - [ ] Add an entry to CHANGELOG.rst
    - [ ] Add yourself it AUTHORS.rst if you don't appear there

    ## Reviewer guidance

    *If you PR has a significant size, give the reviewer some helpful remarks*

    ## Issues addressed

    List the issues solved or partly solved by the PR

    ## Documentation

    If the PR has documentation, link the file here (either .rst in your repo or if built on Read The Docs)

    ## Screenshots (if appropriate)

    They're nice. :)
